==> haskell-tar-conduit-0.3.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar-conduit
version: 0.3.2
id: tar-conduit-0.3.2-AntmqISjEX57Vfz4Q3rN5t
key: tar-conduit-0.3.2-AntmqISjEX57Vfz4Q3rN5t
license: MIT
maintainer: michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch
author: Michael Snoyman
homepage: https://github.com/snoyberg/tar-conduit#readme
synopsis: Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.
category: Data Conduit
abi: 25a154eff3e78658178ef149c9b42a5c
exposed: True
exposed-modules:
    Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules: Data.Conduit.Tar.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tar-conduit-0.3.2
hs-libraries: HStar-conduit-0.3.2-AntmqISjEX57Vfz4Q3rN5t
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-3gq47figCcD3FXjYab6brY directory-1.3.3.0
    filepath-1.4.2.1 safe-exceptions-0.1.7.0-4HYWq3cjfRaKEL4LU0mXWw
    text-1.2.3.1 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html: /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-conduit-0.3.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar-conduit
version: 0.3.2
id: tar-conduit-0.3.2-I0av5yPJQhnHhIHBefC0fC
key: tar-conduit-0.3.2-I0av5yPJQhnHhIHBefC0fC
license: MIT
maintainer: michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch
author: Michael Snoyman
homepage: https://github.com/snoyberg/tar-conduit#readme
synopsis: Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.
category: Data Conduit
abi: 9b6a142fb2dc034932d8b852d8a48e60
exposed: True
exposed-modules:
    Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules: Data.Conduit.Tar.Unix
import-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tar-conduit-0.3.2
hs-libraries: HStar-conduit-0.3.2-I0av5yPJQhnHhIHBefC0fC
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-DEyzgVREq8JGnMpn8fab1M directory-1.3.3.0
    filepath-1.4.2.1 safe-exceptions-0.1.7.0-5f44kNJIxCHCEhTikLHby
    text-1.2.3.1 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html: /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
